------------------------------
-- Localize Lua Globals
------------------------------
local _G = getfenv(0)
local select = _G.select
local format = _G.string.format
local insert = _G.table.insert
local type   = _G.type

------------------------------
-- AddOn Namespace
------------------------------
local LibStub = LibStub

local MODNAME = "Skill Guide"
local addon   = LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L       = LibStub("AceLocale-3.0"):GetLocale(MODNAME)
local private = select(2, ...)

function addon:sortOptimalList(list)
   if not list or type(list) ~= "table" then
      self:Print("list is not a table or undefined")
   end
   
   self:Print("in sort")
   
   local temp = {}
   for i = 1, #list do
      -- get the reagents for this craft item
      local itemId, reagents = DataStore:GetCraftInfo(list[i])
      self:Print(itemId .. " " .. reagents)
   end
end

function addon:BuildOptimalList(profession, spellId)
   if not spellId then
      self:Print("spell id not set, throw error")
   end
   
   -- Get the trade skill table for this spell ID
   local key = format("%s", spellId)
   local skill = self.db.char.tradeskills[key]
   
   -- wipe the old information from the table
   wipe(skill.optimal)
   
   -- insert all the guarenteed skill up recipes into the optimal table
   for i = 1, DataStore:GetNumCraftLines(profession) do
      local isHeader, color, itemId = DataStore:GetCraftLineInfo(profession, i)
      if not isHeader and color == private.constants["optimal"] then
         insert(skill.optimal, itemId)
      end
   end
   
   -- sort the table based on the cost to craft
   addon:sortOptimalList(skill.optimal)
end
